@@ -51,9 +51,6 @@
 /* Define if you have the <sys/select.h> header file.  */
 #define HAVE_SYS_SELECT_H 1
 
-/* Define if you have the <unistd.h> header file.  */
-#define HAVE_UNISTD_H 1
-
 /* Define if you have the <utime.h> header file.  */
 #define HAVE_UTIME_H 1
 
