@@ -1,5 +1,5 @@
 #ifndef LINT
-static char *rcsid="$Id: eph_cmd.c,v 1.19 2000/05/09 13:20:54 crosser Exp $";
+static char *rcsid="$Id: eph_cmd.c,v 1.20 2001/08/28 06:28:01 crosser Exp $";
 #endif
 
 /*
@@ -17,6 +17,9 @@ static char *rcsid="$Id: eph_cmd.c,v 1.19 2000/05/09 13:20:54 crosser Exp $";
 
 /*
 	$Log: eph_cmd.c,v $
+	Revision 1.20  2001/08/28 06:28:01  crosser
+	try make zoom working on newer Oly
+	
 	Revision 1.19  2000/05/09 13:20:54  crosser
 	configure read() with alarm() better.
 	Address signed vs. unsigned arguments
@@ -288,7 +291,7 @@ eph_setvar(eph_iob *iob,int reg,char *val,off_t olength)
 writeagain:
 		if ((rc=eph_writepkt(iob,pkttyp,pktseq,buf,pktsize)))
 			goto fin;
-		rc=eph_waitack(iob,ACKTIMEOUT);
+		rc=eph_waitack(iob,(reg==REG_ZOOM)?BIGACKTIMEOUT:ACKTIMEOUT);
 		if (MAYRETRY(rc) && (count++ < RETRIES)) goto writeagain;
 	}
 	if (count >= RETRIES)
