@@ -1,5 +1,5 @@
 #ifndef LINT
-static char *rcsid="$Id: eph_io.c,v 2.19 2000/07/14 06:35:39 crosser Exp $";
+static char *rcsid="$Id: eph_io.c,v 2.20 2001/05/15 22:21:35 crosser Exp $";
 #endif
 
 /*
@@ -17,6 +17,10 @@ static char *rcsid="$Id: eph_io.c,v 2.19 2000/07/14 06:35:39 crosser Exp $";
 
 /*
 	$Log: eph_io.c,v $
+	Revision 2.20  2001/05/15 22:21:35  crosser
+	README - reflect CVS and www server change to sourceforge
+	eph_io.c - make waitsig() skip 0xff's in addition to NULs
+	
 	Revision 2.19  2000/07/14 06:35:39  crosser
 	reportedly some models return CAN instead of DC1
 	
@@ -518,7 +522,8 @@ int
 eph_waitsig(eph_iob *iob)
 {
 	int rc,count=SKIPNULS;
-	while (((rc=eph_waitchar(iob,INITTIMEOUT)) == 0) && (count-- > 0)) ;
+	while ((((rc=eph_waitchar(iob,INITTIMEOUT)) == 0) || rc == 0xff)
+	       && (count-- > 0)) ;
 	if (rc == 0x15) return 0;
 	eph_error(iob,ERR_BADREAD,"eph_waitsig got %d",rc);
 	return rc;
