@@ -1,5 +1,5 @@
 #ifndef LINT
-static char *rcsid="$Id: eph_iob.c,v 2.6 1999/08/01 21:36:54 crosser Exp $";
+static char *rcsid="$Id: eph_iob.c,v 2.7 1999/12/11 14:10:15 crosser Exp $";
 #endif
 
 /*
@@ -17,6 +17,10 @@ static char *rcsid="$Id: eph_iob.c,v 2.6 1999/08/01 21:36:54 crosser Exp $";
 
 /*
 	$Log: eph_iob.c,v $
+	Revision 2.7  1999/12/11 14:10:15  crosser
+	Support sgtty terminal control
+	Proper "fake speed" handling (needed two values)
+	
 	Revision 2.6  1999/08/01 21:36:54  crosser
 	Modify source to suit ansi2knr
 	(I hate the style that ansi2knr requires but you don't expect me
@@ -100,7 +104,13 @@ eph_new(void (*errorcb)(int errcode,char *errstr),
 	memset((char*)&iob->savetimeouts,0,sizeof(iob->savetimeouts));
 #elif defined(UNIX)
 	iob->fd=-1;
+#if defined(USE_TERMIOS)
 	memset((char*)&iob->savetios,0,sizeof(iob->savetios));
+#elif defined(USE_SGTTY)
+	memset((char*)&iob->savesgtty,0,sizeof(iob->savesgtty));
+#elif defined(USE_TERMIO)
+	memset((char*)&iob->savetio,0,sizeof(iob->savetio));
+#endif
 #elif defined(DOS)
 	iob->fd=-1;
 #else
