@@ -1,5 +1,5 @@
 /*
-	$Id: eph_priv.h,v 2.7 1999/01/17 09:50:55 crosser Exp $
+	$Id: eph_priv.h,v 2.9 2000/07/14 06:35:39 crosser Exp $
 */
 
 /*
@@ -17,6 +17,14 @@
 
 /*
 	$Log: eph_priv.h,v $
+	Revision 2.9  2000/07/14 06:35:39  crosser
+	reportedly some models return CAN instead of DC1
+	
+	Revision 2.8  2000/05/09 13:20:54  crosser
+	configure read() with alarm() better.
+	Address signed vs. unsigned arguments
+	other cleanups to make most notorious compilers happy
+	
 	Revision 2.7  1999/01/17 09:50:55  crosser
 	increase WRT*DELAYs
 
@@ -98,6 +106,7 @@
 #define DC1 0x11
 #define NAK 0x15
 /*#define NAK 0x11*/
+#define CAN 0x18
 
 #define CMD_SETINT 0
 #define CMD_GETINT 1
@@ -112,6 +121,10 @@
 #define SEQ_INITCMD 0x53
 #define SEQ_CMD 0x43
 
+#ifndef O_NDELAY
+#define O_NDELAY O_NONBLOCK
+#endif
+
 typedef struct _eph_pkthdr {
 	unsigned char typ;
 	unsigned char seq;
