@@ -1,9 +1,9 @@
 #ifndef LINT
-static char *rcsid="$Id: eph_read.c,v 2.7 1999/08/01 21:36:54 crosser Exp $";
+static char *rcsid="$Id: eph_read.c,v 2.11 2000/07/14 06:35:39 crosser Exp $";
 #endif
 
 /*
-	Copyright (c) 1997,1998 Eugene G. Crosser
+	Copyright (c) 1997-2000 Eugene G. Crosser
 	Copyright (c) 1998 Bruce D. Lightner (DOS/Windows support)
 
 	You may distribute and/or use for any purpose modified or unmodified
@@ -17,6 +17,21 @@ static char *rcsid="$Id: eph_read.c,v 2.7 1999/08/01 21:36:54 crosser Exp $";
 
 /*
 	$Log: eph_read.c,v $
+	Revision 2.11  2000/07/14 06:35:39  crosser
+	reportedly some models return CAN instead of DC1
+	
+	Revision 2.10  2000/05/09 13:20:54  crosser
+	configure read() with alarm() better.
+	Address signed vs. unsigned arguments
+	other cleanups to make most notorious compilers happy
+	
+	Revision 2.9  2000/05/02 22:26:35  crosser
+	A few things incorporated from John Bowman's Nikon specific diffs
+	
+	Revision 2.8  2000/05/02 12:13:32  crosser
+	some better debugging output
+	alarm() based timeouted read (build with "--without-select")
+	
 	Revision 2.7  1999/08/01 21:36:54  crosser
 	Modify source to suit ansi2knr
 	(I hate the style that ansi2knr requires but you don't expect me
@@ -59,6 +74,7 @@ static char *rcsid="$Id: eph_read.c,v 2.7 1999/08/01 21:36:54 crosser Exp $";
 #include <errno.h>
 
 #include "eph_io.h"
+#include "eph_priv.h"
 
 #ifdef MSWINDOWS
 #define ERRNO GetLastError()
@@ -150,6 +166,61 @@ eph_readt(eph_iob *iob,char *buf,size_t length,long timeout_usec,int *rc)
 # endif
 #endif
 
+#ifdef USE_ALARMED_READ
+
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
+static RETSIGTYPE
+alrmhdl(int sig)
+{}
+
+size_t
+eph_readt(eph_iob *iob,char *buf,size_t length,long timeout_usec,int *rc)
+{
+	int ret,timeout_sec;
+	RETSIGTYPE *oldsig;
+
+	if (length == 0) return 0;
+
+	if (timeout_usec == 0L) {
+		*rc=1;
+		if (fcntl(iob->fd,F_SETFL,iob->flag|O_NDELAY) == -1)
+			return (size_t)-1;
+		ret=read(iob->fd,buf,length);
+		if (fcntl(iob->fd,F_SETFL,iob->flag) == -1)
+			return (size_t)-1;
+		if ((ret == -1) && (errno == EAGAIN)) {
+			ret=0;
+			*rc=0;
+		}
+		return ret;
+	}
+
+#ifdef HAVE_RESTARTABLE_SYSCALLS
+	(void)siginterrupt(SIGALRM,1);
+#endif
+
+	timeout_sec=timeout_usec/1000000;
+	if (timeout_sec < 2) timeout_sec=2;
+	oldsig=signal(SIGALRM,alrmhdl);
+	alarm((unsigned)timeout_sec);
+	*rc=1;
+	ret=read(iob->fd,buf,length);
+	if ((ret == -1) && (errno == EINTR)) {
+		ret=0;
+		*rc=0;
+	}
+	alarm(0);
+	signal(SIGALRM,oldsig);
+	return ret;
+}
+
+#else /* USE_ALARMED_READ */
 
 size_t
 eph_readt(eph_iob *iob,char *buf,size_t length,long timeout_usec,int *rc)
@@ -171,11 +242,13 @@ eph_readt(eph_iob *iob,char *buf,size_t length,long timeout_usec,int *rc)
 	if ((*rc) == 0) {
 		return 0;
 	}
-	if (((*rc) < 0) || (FD_ISSET(iob->fd,&efds))) return -1;
+	if (((*rc) < 0) || (FD_ISSET(iob->fd,&efds))) return (size_t)-1;
 
 	return read(iob->fd,buf,length);
 }
 
+#endif /* USE_ALARMED_READ */
+
 #elif defined(DOS)
 
 #include <dos.h>
