@@ -1,5 +1,5 @@
 #ifndef LINT
-static char *rcsid="$Id: photopc.c,v 2.83 2001/01/12 23:26:40 crosser Exp $";
+static char *rcsid="$Id: photopc.c,v 2.87 2003/03/14 15:25:36 crosser Exp $";
 #endif
 
 /*
@@ -17,6 +17,19 @@ static char *rcsid="$Id: photopc.c,v 2.83 2001/01/12 23:26:40 crosser Exp $";
 
 /*
 	$Log: photopc.c,v $
+	Revision 2.87  2003/03/14 15:25:36  crosser
+	dev version: trying to workaround phantom entries in the root directory
+	
+	Revision 2.86  2001/08/28 06:51:25  crosser
+	oops, the value is multiplied by 10 before becoming 2 bytes
+	And btw change dev subrelease
+	
+	Revision 2.85  2001/08/28 06:40:10  crosser
+	change website reference to sourceforge
+	
+	Revision 2.84  2001/08/28 06:28:01  crosser
+	try make zoom working on newer Oly
+	
 	Revision 2.83  2001/01/12 23:26:40  crosser
 	new release, avoid strncasecmp, change copyright year
 	
@@ -432,7 +445,7 @@ numphotos(eph_iob *iob)
 	if (eph_getint(iob,10,&r10)) {
 		r10=-1;
 	}
-	return (r10>r40)?r10:r40;
+	return (r10==-1)?r40:r10;
 }
 
 static int
@@ -908,13 +921,16 @@ int
 zoom(eph_iob *iob,int argc,char *argv[])
 {
 	double val;
+	unsigned int code;
 	char buffer[]={0,0,0,0,10,0,0,0};
 
-	if ((val=atof(argv[1])) <= 0.0 || val >= 26.0) {
+	if ((val=atof(argv[1])) <= 0.05 || val > 6553.0) {
 		fprintf(stderr,"bad zoom value `%s'\n",argv[1]);
 		return -1;
 	}
-	buffer[0]=(unsigned int)(10.0*val-0.5);
+	code=(unsigned int)(10.0*val-0.5);
+	buffer[0]=code&0xff;
+	buffer[1]=(code>>8)&0xff;
 	return eph_setvar(iob,71,buffer,sizeof(buffer));
 }
 
@@ -1475,6 +1491,11 @@ listfiles(eph_iob *iob,char *path)
 		return -1;
 	}
 	if (have_folders) printf("%s: ",path);
+	if (have_folders && max && (strlen(path) < 2)) {
+		printf(" [%ld entr%s in root folder, likely bug]\n",
+			max,(max==1)?"y":"ies");
+		return 0;
+	}
 	if (max)
 		printf("total %lu\n"
 		"No.    Size R P Date and Time                    Filename\n",
@@ -1487,18 +1508,18 @@ listfiles(eph_iob *iob,char *path)
 	for (j=1;j<=max;j++) {
 		printf("%3ld ",j);
 		if ((rc=eph_setint(iob,4,j)) == DC1) {
-			printf("%3ld N/A\n",j);
+			printf("N/A\n");
 			break;
 		} else if (rc) {
-			printf("%3ld FAIL\n",j);
+			printf("FAIL\n");
 			break;
 		}
 		if ((rc=eph_getint(iob,12,&res)) == DC1) {
-			printf("%3ld N/A    ",j);
+			printf("N/A    ");
 		} else if (rc) {
-			printf("%3ld FAIL   ",j);
+			printf("FAIL   ");
 		} else {
-			printf("%3ld %7ld ",j,res);
+			printf("%7ld ",res);
 		}
 		if ((rc=eph_getvar(iob,47,&buffer,&bufsize)) == DC1) {
 			printf("N/A\n");
@@ -1515,7 +1536,7 @@ listfiles(eph_iob *iob,char *path)
 		printf("%c ",res?'P':'-');
 		res=(long)(buffer[20]&0xff)+((long)(buffer[21]&0xff)<<8)+
 			((long)(buffer[22]&0xff)<<16)+((long)(buffer[23]&0xff)<<24);
-		if (res != -1L) printf("%8s",ctimetz(&res,usetimezone));
+		if (res > 0L) printf("%8s",ctimetz(&res,usetimezone));
 		else printf("N/A                         ");
 		if ((rc=eph_getvar(iob,79,&buffer,&bufsize)) == DC1) {
 			printf(" N/A\n");
@@ -1543,6 +1564,11 @@ llistfiles(eph_iob *iob, char *path)
 		return -1;
 	}
 	if (have_folders) printf("%s: ",path);
+	if (have_folders && max && (strlen(path) < 2)) {
+		printf(" [%ld entr%s in root folder, likely bug]\n",
+			max,(max==1)?"y":"ies");
+		return 0;
+	}
 	if (max)
 		printf("total %lu\n"
 		"No. P    Size R F Shuttr Date and Time\n",
@@ -2366,7 +2392,7 @@ showversion(char *name)
 #endif
 		);
 	printf("     Copyright (c) 1997-2001 Eugene Crosser and Bruce Lightner\n");
-	printf("     URL: http://www.average.org/digicam/\n");
+	printf("     URL: http://photopc.sourceforge.net/\n");
 }
 
 int
