@@ -1,5 +1,5 @@
 #ifndef LINT
-static char *rcsid="$Id: usleep.c,v 2.8 1999/08/01 21:36:54 crosser Exp $";
+static char *rcsid="$Id: usleep.c,v 2.9 2000/05/09 13:20:54 crosser Exp $";
 #endif
 
 /*
@@ -17,6 +17,11 @@ static char *rcsid="$Id: usleep.c,v 2.8 1999/08/01 21:36:54 crosser Exp $";
 
 /*
 	$Log: usleep.c,v $
+	Revision 2.9  2000/05/09 13:20:54  crosser
+	configure read() with alarm() better.
+	Address signed vs. unsigned arguments
+	other cleanups to make most notorious compilers happy
+	
 	Revision 2.8  1999/08/01 21:36:54  crosser
 	Modify source to suit ansi2knr
 	(I hate the style that ansi2knr requires but you don't expect me
@@ -80,6 +85,13 @@ usleep(unsigned int useconds)
 
 	nanosleep (&ts, NULL);
 }
+#elif HAVE_SNOOZE
+extern void snooze(long long timeout);
+void
+usleep (unsigned long usec)
+{
+	snooze((long long)usec);
+}
 #elif HAVE_SELECT
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
