@@ -54,9 +54,6 @@
 /* Define if you have the <sys/utime.h> header file.  */
 #define HAVE_SYS_UTIME_H
 
-/* Define if you have the <unistd.h> header file.  */
-#define HAVE_UNISTD_H 1
-
 /* Define if compiler has function prototypes */
 #define PROTOTYPES 1
 
